@@ -55,8 +55,3 @@ def main(argv=None):
             preamble=args.preamble,
         )
     )
-
-
-if __name__ == "__main__":
-    logging.basicConfig(level=logging.INFO)
-    main()
